@@ -1,7 +1,16 @@
-#include "salalib/mapconverter.h"
-#include "salalib/tidylines.h"
+// SPDX-FileCopyrightText: 2000-2010 University College London, Alasdair Turner
+// SPDX-FileCopyrightText: 2011-2012 Tasos Varoudis
+// SPDX-FileCopyrightText: 2017 Christian Sailer
+// SPDX-FileCopyrightText: 2018-2024 Petros Koutsolampros
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
+#include "mapconverter.h"
+
+#include "tidylines.h"
 
 #include "genlib/exceptions.h"
+#include "genlib/stringutils.h"
 
 #include <numeric>
 
@@ -52,7 +61,8 @@ MapConverter::convertDrawingToAxial(Communicator *comm, const std::string &name,
         throw depthmapX::RuntimeException("Failed to convert lines");
     }
 
-    // quick tidy removes very short and duplicate lines, but does not merge overlapping lines
+    // quick tidy removes very short and duplicate lines, but does not merge
+    // overlapping lines
     TidyLines tidier;
     tidier.quicktidy(lines, region);
     if (lines.size() == 0) {
@@ -87,8 +97,8 @@ MapConverter::convertDrawingToAxial(Communicator *comm, const std::string &name,
 }
 
 // create axial map directly from data maps
-// note that actually should be able to merge this code with the line layers, now both use similar
-// code
+// note that actually should be able to merge this code with the line layers,
+// now both use similar code
 
 std::unique_ptr<ShapeGraph> MapConverter::convertDataToAxial(Communicator *comm,
                                                              const std::string &name,
@@ -108,7 +118,7 @@ std::unique_ptr<ShapeGraph> MapConverter::convertDataToAxial(Communicator *comm,
     // add all visible layers to the set of polygon lines...
 
     int count = 0;
-    for (auto shape : shapemap.getAllShapes()) {
+    for (const auto &shape : shapemap.getAllShapes()) {
         int key = shape.first;
 
         std::vector<Line> shapeLines = shape.second.getAsLines();
@@ -121,7 +131,8 @@ std::unique_ptr<ShapeGraph> MapConverter::convertDataToAxial(Communicator *comm,
         throw depthmapX::RuntimeException("No lines found in data map");
     }
 
-    // quick tidy removes very short and duplicate lines, but does not merge overlapping lines
+    // quick tidy removes very short and duplicate lines, but does not merge
+    // overlapping lines
     TidyLines tidier;
     tidier.quicktidy(lines, region);
     if (lines.size() == 0) {
@@ -259,7 +270,7 @@ std::unique_ptr<ShapeGraph> MapConverter::convertDataToConvex(Communicator *,
         }
     }
 
-    for (auto refShape : refShapes) {
+    for (auto &refShape : refShapes) {
         if (copydata) {
             for (size_t i = 0; i < input.getNumColumns(); ++i) {
                 extraAttr[attrCols[size_t(i)]] =
@@ -292,7 +303,8 @@ MapConverter::convertDrawingToSegment(Communicator *comm, const std::string &nam
         comm->CommPostMessage(Communicator::CURRENT_STEP, 1);
     }
 
-    // second number in internal pair is used to say which layer it originated from
+    // second number in internal pair is used to say which layer it originated
+    // from
     std::map<int, std::pair<Line, int>> lines;
 
     bool recordlayer = false;
@@ -328,7 +340,8 @@ MapConverter::convertDrawingToSegment(Communicator *comm, const std::string &nam
         throw depthmapX::RuntimeException("No lines found in drawing");
     }
 
-    // quick tidy removes very short and duplicate lines, but does not merge overlapping lines
+    // quick tidy removes very short and duplicate lines, but does not merge
+    // overlapping lines
     TidyLines tidier;
     tidier.quicktidy(lines, region);
     if (lines.size() == 0) {
@@ -363,8 +376,8 @@ MapConverter::convertDrawingToSegment(Communicator *comm, const std::string &nam
     return usermap;
 }
 
-// create segment map directly from data maps (ultimately, this will replace the line layers
-// version)
+// create segment map directly from data maps (ultimately, this will replace the
+// line layers version)
 
 std::unique_ptr<ShapeGraph> MapConverter::convertDataToSegment(Communicator *comm,
                                                                const std::string &name,
@@ -383,7 +396,7 @@ std::unique_ptr<ShapeGraph> MapConverter::convertDataToSegment(Communicator *com
     // add all visible layers to the set of polygon lines...
 
     int count = 0;
-    for (auto shape : shapemap.getAllShapes()) {
+    for (const auto &shape : shapemap.getAllShapes()) {
         int key = shape.first;
         std::vector<Line> shapeLines = shape.second.getAsLines();
         for (Line line : shapeLines) {
@@ -395,7 +408,8 @@ std::unique_ptr<ShapeGraph> MapConverter::convertDataToSegment(Communicator *com
         throw depthmapX::RuntimeException("No lines found in data map");
     }
 
-    // quick tidy removes very short and duplicate lines, but does not merge overlapping lines
+    // quick tidy removes very short and duplicate lines, but does not merge
+    // overlapping lines
     TidyLines tidier;
     tidier.quicktidy(lines, region);
 
@@ -466,8 +480,8 @@ std::unique_ptr<ShapeGraph> MapConverter::convertDataToSegment(Communicator *com
         usermap->makeLineShape(line.second.first, false, false, extraAttr);
     }
 
-    // start to be a little bit more efficient about memory now we are hitting the limits
-    // from time to time:
+    // start to be a little bit more efficient about memory now we are hitting the
+    // limits from time to time:
     if (!copydata) {
         lines.clear();
     }
@@ -478,7 +492,8 @@ std::unique_ptr<ShapeGraph> MapConverter::convertDataToSegment(Communicator *com
     return usermap;
 }
 
-// stubremoval is fraction of overhanging line length before axial "stub" is removed
+// stubremoval is fraction of overhanging line length before axial "stub" is
+// removed
 std::unique_ptr<ShapeGraph>
 MapConverter::convertAxialToSegment(Communicator *, ShapeGraph &axialMap, const std::string &name,
                                     bool keeporiginal, bool copydata, double stubremoval) {
@@ -487,7 +502,8 @@ MapConverter::convertAxialToSegment(Communicator *, ShapeGraph &axialMap, const
 
     axialMap.makeSegmentMap(lines, connectionset, stubremoval);
 
-    // destroy unnecessary parts of axial map as quickly as possible in order not to overload memory
+    // destroy unnecessary parts of axial map as quickly as possible in order not
+    // to overload memory
     if (!keeporiginal) {
         axialMap.getAllShapes().clear();
         axialMap.getConnections().clear();
@@ -496,7 +512,7 @@ MapConverter::convertAxialToSegment(Communicator *, ShapeGraph &axialMap, const
     // create map layer...
     std::unique_ptr<ShapeGraph> segmap(new ShapeGraph(name, ShapeMap::SEGMENTMAP));
 
-    segmap->init(int(lines.size()), axialMap.getRegion());
+    segmap->init(lines.size(), axialMap.getRegion());
     segmap->initialiseAttributesSegment();
 
     for (size_t k = 0; k < lines.size(); k++) {
@@ -516,7 +532,8 @@ MapConverter::convertAxialToSegment(Communicator *, ShapeGraph &axialMap, const
     if (copydata) {
         segmap->pushAxialValues(axialMap);
     }
-    // destroy unnecessary parts of axial map as quickly as possible in order not to overload memory
+    // destroy unnecessary parts of axial map as quickly as possible in order not
+    // to overload memory
     if (!keeporiginal) {
         axialMap.getAttributeTable().clear();
     }
