@@ -1,41 +1,28 @@
-// sala - a component of the depthmapX - spatial network analysis platform
-// Copyright (C) 2011-2012, Tasos Varoudis
-// Copyright (C) 2024, Petros Koutsolampros
-
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-FileCopyrightText: 2011-2012 Tasos Varoudis
+// SPDX-FileCopyrightText: 2024 Petros Koutsolampros
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
 // Interface: the meta graph loads and holds all sorts of arbitrary data...
 
-#include "salalib/fileproperties.h"
-#include "salalib/importtypedefs.h"
-
-// still call paftl:
-#include "salalib/agents/agentengine.h" // for agent engine interface
-#include "salalib/connector.h"
-#include "salalib/spacepix.h"
-
-// still need paftl:
-#include "salalib/pointdata.h"
-#include "salalib/shapegraph.h"
-#include "salalib/shapemap.h"
+#include "agents/agentengine.h" // for agent engine interface
+#include "connector.h"
+#include "fileproperties.h"
+#include "importtypedefs.h"
+#include "options.h"
+#include "pointdata.h"
+#include "shapegraph.h"
+#include "shapemap.h"
+#include "spacepix.h"
 
+#include "genlib/bsptree.h"
 #include "genlib/p2dpoly.h"
 
 #include <memory>
 #include <mutex>
+#include <optional>
 #include <vector>
 
 ///////////////////////////////////////////////////////////////////////////////////
@@ -67,7 +54,9 @@ class MetaGraph : public FileProperties {
     // TODO: drawing state functions/fields that should be eventually removed
     void makeViewportShapes(const QtRegion &viewport) const;
     bool findNextShape(bool &nextlayer) const;
-    const SalaShape &getNextShape() const { return m_drawingFiles[m_current_layer].getNextShape(); }
+    const SalaShape &getNextShape() const {
+        return m_drawingFiles[static_cast<size_t>(m_current_layer)].getNextShape();
+    }
     mutable int m_current_layer;
 
     enum {
@@ -104,7 +93,7 @@ class MetaGraph : public FileProperties {
     std::vector<ShapeMap> m_dataMaps;
 
     std::vector<std::unique_ptr<ShapeGraph>> m_shapeGraphs;
-    int m_displayed_shapegraph = -1;
+    std::optional<size_t> m_displayed_shapegraph = std::nullopt;
 
   public:
     MetaGraph(std::string name = "");
@@ -116,10 +105,17 @@ class MetaGraph : public FileProperties {
     }
 
     std::vector<PointMap> &getPointMaps() { return m_pointMaps; }
-    PointMap &getDisplayedPointMap() { return m_pointMaps[m_displayed_pointmap]; }
-    const PointMap &getDisplayedPointMap() const { return m_pointMaps[m_displayed_pointmap]; }
-    void setDisplayedPointMapRef(int i) { m_displayed_pointmap = i; }
-    int getDisplayedPointMapRef() const { return m_displayed_pointmap; }
+    bool hasDisplayedPointMap() const { return m_displayed_pointmap.has_value(); }
+    PointMap &getDisplayedPointMap() { return m_pointMaps[m_displayed_pointmap.value()]; }
+    const PointMap &getDisplayedPointMap() const {
+        return m_pointMaps[m_displayed_pointmap.value()];
+    }
+    void setDisplayedPointMapRef(size_t map) {
+        if (m_displayed_pointmap.has_value() && m_displayed_pointmap != map)
+            getDisplayedPointMap().clearSel();
+        m_displayed_pointmap = map;
+    }
+    size_t getDisplayedPointMapRef() const { return m_displayed_pointmap.value(); }
     void redoPointMapBlockLines() // (flags blockedlines, but also flags that you need to rebuild a
                                   // bsp tree if you have one)
     {
@@ -127,28 +123,29 @@ class MetaGraph : public FileProperties {
             pointMap.m_blockedlines = false;
         }
     }
-    int addNewPointMap(const std::string &name = std::string("VGA Map"));
+    size_t addNewPointMap(const std::string &name = std::string("VGA Map"));
 
   private:
     std::vector<PointMap> m_pointMaps;
-    int m_displayed_pointmap = -1;
+    std::optional<size_t> m_displayed_pointmap = std::nullopt;
 
     // helpful to know this for creating fewest line maps, although has to be reread at input
-    int m_all_line_map = -1;
+    std::optional<size_t> m_all_line_map = std::nullopt;
 
-    void removePointMap(int i) {
-        if (m_displayed_pointmap >= i)
-            m_displayed_pointmap--;
-        if (m_displayed_pointmap < 0)
-            m_displayed_pointmap = 0;
-        m_pointMaps.erase(m_pointMaps.begin() + i);
+    void removePointMap(size_t i) {
+        if (m_displayed_pointmap.has_value()) {
+            if (m_pointMaps.size() == 1)
+                m_displayed_pointmap = std::nullopt;
+            else if (m_displayed_pointmap.value() != 0 && m_displayed_pointmap.value() >= i)
+                m_displayed_pointmap.value()--;
+        }
+        m_pointMaps.erase(std::next(m_pointMaps.begin(), static_cast<int>(i)));
     }
 
     bool readPointMaps(std::istream &stream);
     bool writePointMaps(std::ofstream &stream, bool displayedmaponly = false);
 
   public:
-
     int getState() const { return m_state; }
     // use with caution: only very rarely needed outside MetaGraph itself
     void setState(int state) { m_state = state; }
@@ -184,9 +181,9 @@ class MetaGraph : public FileProperties {
     bool polyClose(int shape_ref);
     bool polyCancel(int shape_ref);
     //
-    int addShapeGraph(std::unique_ptr<ShapeGraph> &shapeGraph);
-    int addShapeGraph(const std::string &name, int type);
-    int addShapeMap(const std::string &name);
+    size_t addShapeGraph(std::unique_ptr<ShapeGraph> &shapeGraph);
+    size_t addShapeGraph(const std::string &name, int type);
+    size_t addShapeMap(const std::string &name);
     void removeDisplayedMap();
     //
     // various map conversions
@@ -218,7 +215,7 @@ class MetaGraph : public FileProperties {
     bool analyseTopoMet(Communicator *communicator,
                         Options options); // <- options copied to keep thread safe
     //
-    bool hasAllLineMap() { return m_all_line_map != -1; }
+    bool hasAllLineMap() { return m_all_line_map.has_value(); }
     bool hasFewestLineMaps() {
         for (const auto &shapeGraph : m_shapeGraphs) {
             if (shapeGraph->getName() == "Fewest-Line Map (Subsets)" ||
@@ -231,61 +228,73 @@ class MetaGraph : public FileProperties {
         return false;
     }
     enum { PUSH_FUNC_MAX = 0, PUSH_FUNC_MIN = 1, PUSH_FUNC_AVG = 2, PUSH_FUNC_TOT = 3 };
-    bool pushValuesToLayer(int desttype, int destlayer, int push_func, bool count_col = false);
-    bool pushValuesToLayer(int sourcetype, int sourcelayer, int desttype, int destlayer, int col_in,
-                           int col_out, int push_func, bool count_col = false);
+    bool pushValuesToLayer(int desttype, size_t destlayer, int push_func, bool count_col = false);
+    bool pushValuesToLayer(int sourcetype, size_t sourcelayer, int desttype, size_t destlayer,
+                           std::optional<size_t> col_in, size_t col_out, int push_func,
+                           bool count_col = false);
     //
-    int getDisplayedMapRef() const;
+    std::optional<size_t> getDisplayedMapRef() const;
     //
     // NB -- returns 0 (not editable), 1 (editable off) or 2 (editable on)
     int isEditable() const;
     bool canUndo() const;
     void undo();
 
-    size_t m_displayed_datamap = -1;
-    ShapeMap &getDisplayedDataMap() { return m_dataMaps[m_displayed_datamap]; }
-    const ShapeMap &getDisplayedDataMap() const { return m_dataMaps[m_displayed_datamap]; }
-    size_t getDisplayedDataMapRef() const { return m_displayed_datamap; }
+    std::optional<size_t> m_displayed_datamap = std::nullopt;
+    bool hasDisplayedDataMap() const { return m_displayed_datamap.has_value(); }
+    ShapeMap &getDisplayedDataMap() { return m_dataMaps[m_displayed_datamap.value()]; }
+    const ShapeMap &getDisplayedDataMap() const { return m_dataMaps[m_displayed_datamap.value()]; }
+    size_t getDisplayedDataMapRef() const { return m_displayed_datamap.value(); }
 
     void removeDataMap(size_t i) {
-        if (m_displayed_datamap >= i && i > 0)
-            m_displayed_datamap--;
-        m_dataMaps.erase(m_dataMaps.begin() + i);
+        if (m_displayed_datamap.has_value()) {
+            if (m_dataMaps.size() == 1)
+                m_displayed_datamap = std::nullopt;
+            else if (m_displayed_datamap.value() != 0 && m_displayed_datamap.value() >= i)
+                m_displayed_datamap.value()--;
+        }
+        m_dataMaps.erase(std::next(m_dataMaps.begin(), static_cast<int>(i)));
     }
 
     void setDisplayedDataMapRef(size_t map) {
-        if (static_cast<int>(m_displayed_datamap) != -1 && m_displayed_datamap != map)
-            m_dataMaps[m_displayed_datamap].clearSel();
+        if (m_displayed_datamap.has_value() && m_displayed_datamap != map)
+            getDisplayedDataMap().clearSel();
         m_displayed_datamap = map;
     }
 
-    template <class T> size_t getMapRef(std::vector<T> &maps, const std::string &name) const {
+    template <class T>
+    std::optional<size_t> getMapRef(std::vector<T> &maps, const std::string &name) const {
         // note, only finds first map with this name
         for (size_t i = 0; i < maps.size(); i++) {
             if (maps[i].getName() == name)
-                return i;
+                return std::optional<size_t>{i};
         }
-        return -1;
+        return std::nullopt;
     }
 
     std::vector<std::unique_ptr<ShapeGraph>> &getShapeGraphs() { return m_shapeGraphs; }
-    ShapeGraph &getDisplayedShapeGraph() { return *m_shapeGraphs[m_displayed_shapegraph].get(); }
-    const ShapeGraph &getDisplayedShapeGraph() const {
-        return *m_shapeGraphs[m_displayed_shapegraph].get();
+    bool hasDisplayedShapeGraph() const { return m_displayed_shapegraph.has_value(); }
+    ShapeGraph &getDisplayedShapeGraph() {
+        return *m_shapeGraphs[m_displayed_shapegraph.value()].get();
     }
-    void setDisplayedShapeGraphRef(int map) {
-        if (m_displayed_shapegraph != -1 && m_displayed_shapegraph != map)
-            m_shapeGraphs[size_t(m_displayed_shapegraph)]->clearSel();
+    const ShapeGraph &getDisplayedShapeGraph() const {
+        return *m_shapeGraphs[m_displayed_shapegraph.value()].get();
+    }
+    void setDisplayedShapeGraphRef(size_t map) {
+        if (m_displayed_shapegraph.has_value() && m_displayed_shapegraph != map)
+            getDisplayedShapeGraph().clearSel();
         m_displayed_shapegraph = map;
     }
-    int getDisplayedShapeGraphRef() const { return m_displayed_shapegraph; }
+    size_t getDisplayedShapeGraphRef() const { return m_displayed_shapegraph.value(); }
 
-    void removeShapeGraph(int i) {
-        if (m_displayed_shapegraph >= i)
-            m_displayed_shapegraph--;
-        if (m_displayed_shapegraph < 0)
-            m_displayed_shapegraph = 0;
-        m_shapeGraphs.erase(m_shapeGraphs.begin() + i);
+    void removeShapeGraph(size_t i) {
+        if (m_displayed_shapegraph.has_value()) {
+            if (m_shapeGraphs.size() == 1)
+                m_displayed_shapegraph = std::nullopt;
+            else if (m_displayed_shapegraph.value() != 0 && m_displayed_shapegraph.value() >= i)
+                m_displayed_shapegraph.value()--;
+        }
+        m_shapeGraphs.erase(std::next(m_shapeGraphs.begin(), static_cast<int>(i)));
     }
 
     bool readShapeGraphs(std::istream &stream);
@@ -304,27 +313,36 @@ class MetaGraph : public FileProperties {
     //
     int getDisplayedAttribute() const;
     void setDisplayedAttribute(int col);
-    int addAttribute(const std::string &name);
+    std::optional<size_t> addAttribute(const std::string &name);
     void removeAttribute(int col);
-    bool isAttributeLocked(int col);
-    AttributeTable &getAttributeTable(int type = -1, int layer = -1);
-    const AttributeTable &getAttributeTable(int type = -1, int layer = -1) const;
-    LayerManagerImpl &getLayers(int type = -1, int layer = -1);
-    const LayerManagerImpl &getLayers(int type = -1, int layer = -1) const;
-    AttributeTableHandle &getAttributeTableHandle(int type = -1, int layer = -1);
-    const AttributeTableHandle &getAttributeTableHandle(int type = -1, int layer = -1) const;
+    bool isAttributeLocked(size_t col);
+    AttributeTable &getAttributeTable(std::optional<size_t> type = std::nullopt,
+                                      std::optional<size_t> layer = std::nullopt);
+    const AttributeTable &getAttributeTable(std::optional<size_t> type = std::nullopt,
+                                            std::optional<size_t> layer = std::nullopt) const;
+    LayerManagerImpl &getLayers(int type = -1, std::optional<size_t> layer = std::nullopt);
+    const LayerManagerImpl &getLayers(int type = -1,
+                                      std::optional<size_t> layer = std::nullopt) const;
+    AttributeTableHandle &getAttributeTableHandle(int type = -1,
+                                                  std::optional<size_t> layer = std::nullopt);
+    const AttributeTableHandle &
+    getAttributeTableHandle(int type = -1, std::optional<size_t> layer = std::nullopt) const;
 
     int getLineFileCount() const { return (int)m_drawingFiles.size(); }
 
     // Quick mod - TV
-    const std::string &getLineFileName(int file) const { return m_drawingFiles[file].getName(); }
-    int getLineLayerCount(int file) const { return (int)m_drawingFiles[file].m_spacePixels.size(); }
-
-    ShapeMap &getLineLayer(int file, int layer) {
-        return m_drawingFiles[file].m_spacePixels[layer];
+    const std::string &getLineFileName(size_t fileIdx) const {
+        return m_drawingFiles[fileIdx].getName();
     }
-    const ShapeMap &getLineLayer(int file, int layer) const {
-        return m_drawingFiles[file].m_spacePixels[layer];
+    size_t getLineLayerCount(size_t fileIdx) const {
+        return m_drawingFiles[fileIdx].m_spacePixels.size();
+    }
+
+    ShapeMap &getLineLayer(size_t fileIdx, size_t layerIdx) {
+        return m_drawingFiles[fileIdx].m_spacePixels[layerIdx];
+    }
+    const ShapeMap &getLineLayer(size_t fileIdx, size_t layerIdx) const {
+        return m_drawingFiles[fileIdx].m_spacePixels[layerIdx];
     }
     //
     // Some error handling -- the idea is that you catch the error in MetaGraph,
@@ -414,15 +432,15 @@ class MetaGraph : public FileProperties {
         else if (m_state & POINTMAPS &&
                  !getDisplayedPointMap().isProcessed()) // this is a default select application
             return getDisplayedPointMap().setCurSel(r, add);
-        else if (m_state & DATAMAPS) // I'm not sure why this is a possibility, but it appears you
-                                     // might have state & DATAMAPS without VIEWDATA...
+        else if (m_state & DATAMAPS) // I'm not sure why this is a possibility, but it appears
+                                     // you might have state & DATAMAPS without VIEWDATA...
             return getDisplayedDataMap().setCurSel(r, add);
         else
             return false;
     }
     bool clearSel() {
-        // really needs a separate clearSel for the datalayers... at the moment this is handled in
-        // PointMap
+        // really needs a separate clearSel for the datalayers... at the moment this is handled
+        // in PointMap
         if (m_view_class & VIEWVGA)
             return getDisplayedPointMap().clearSel();
         else if (m_view_class & VIEWAXIAL)
@@ -503,7 +521,8 @@ class MetaGraph : public FileProperties {
     //
   public:
     // thru vision
-    bool analyseThruVision(Communicator *comm = NULL, int gatelayer = -1);
+    bool analyseThruVision(Communicator *comm = NULL,
+                           std::optional<size_t> gatelayer = std::nullopt);
     // BSP tree for making isovists
   protected:
     BSPNode *m_bsp_root;
@@ -515,8 +534,8 @@ class MetaGraph : public FileProperties {
     // returns 0: fail, 1: made isovist, 2: made isovist and added new shapemap layer
     int makeIsovist(Communicator *communicator, const Point2f &p, double startangle = 0,
                     double endangle = 0, bool simple_version = true);
-    std::set<std::string> setIsovistData(Isovist &isovist, AttributeTable &table,
-                                         AttributeRow &row, bool simple_version);
+    std::set<std::string> setIsovistData(Isovist &isovist, AttributeTable &table, AttributeRow &row,
+                                         bool simple_version);
     // returns 0: fail, 1: made isovist, 2: made isovist and added new shapemap layer
     int makeIsovistPath(Communicator *communicator, double fov_angle = 2.0 * M_PI,
                         bool simple_version = true);
@@ -538,7 +557,7 @@ class MetaGraph : public FileProperties {
     };
     // likely to use communicator if too slow...
     int readFromFile(const std::string &filename);
-    int readFromStream(std::istream &stream, const std::string &filename);
+    int readFromStream(std::istream &stream, const std::string &);
     int write(const std::string &filename, int version, bool currentlayer = false);
     //
     std::vector<SimpleLine> getVisibleDrawingLines();
