@@ -1,27 +1,16 @@
-// sala - a component of the depthmapX - spatial network analysis platform
-// Copyright (C) 2011-2012, Tasos Varoudis
+// SPDX-FileCopyrightText: 2011-2012 Tasos Varoudis
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
+#pragma once
 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-#ifndef __POINTDATA_H__
-#define __POINTDATA_H__
+#include "attributetable.h"
+#include "point.h"
+#include "spacepixfile.h"
 
+#include "genlib/comm.h"
 #include "genlib/exceptions.h"
-#include "salalib/attributetable.h"
-#include "salalib/options.h"
-#include "salalib/point.h"
-#include "salalib/spacepixfile.h"
+
 #include <deque>
 #include <set>
 #include <vector>
@@ -104,15 +93,13 @@ class PointMap : public PixelBase {
     LayerManagerImpl m_layers;
 
   public:
-    PointMap(const QtRegion &parentRegion,
-             const std::string &name = std::string("VGA Map"));
+    PointMap(const QtRegion &parentRegion, const std::string &name = std::string("VGA Map"));
     virtual ~PointMap() {}
-    void copy(const PointMap &other);
+    void copy(const PointMap &sourcemap, bool copypoints = false, bool copyattributes = false);
     const std::string &getName() const { return m_name; }
 
     PointMap(PointMap &&other)
-        : m_parentRegion(std::move(other.m_parentRegion)),
-          m_points(std::move(other.m_points)),
+        : m_parentRegion(std::move(other.m_parentRegion)), m_points(std::move(other.m_points)),
           m_attributes(std::move(other.m_attributes)),
           m_attribHandle(std::move(other.m_attribHandle)), m_layers(std::move(other.m_layers)) {
         copy(other);
@@ -130,7 +117,7 @@ class PointMap : public PixelBase {
     PointMap(const PointMap &) = delete;
     PointMap &operator=(const PointMap &) = delete;
 
-    void communicate(time_t &atime, Communicator *comm, int record);
+    void communicate(time_t &atime, Communicator *comm, size_t record);
     // constrain is constrain to existing rows / cols
     PixelRef pixelate(const Point2f &p, bool constrain = true, int scalefactor = 1) const;
     Point2f depixelate(const PixelRef &p, double scalefactor = 1.0) const; // Inlined below
@@ -161,7 +148,7 @@ class PointMap : public PixelBase {
     bool canUndo() const { return !m_processed && m_undocounter != 0; }
     void outputPoints(std::ostream &stream, char delim);
     void outputMergeLines(std::ostream &stream, char delim);
-    int tagState(bool settag);
+    size_t tagState(bool settag);
     bool sparkGraph2(Communicator *comm, bool boundarygraph, double maxdist);
     bool unmake(bool removeLinks);
     bool sparkPixel2(PixelRef curs, int make, double maxdist = -1.0);
@@ -248,8 +235,8 @@ class PointMap : public PixelBase {
     mutable int m_displayed_attribute;
 
   public:
-    int addAttribute(const std::string &name) { return m_attributes->insertOrResetColumn(name); }
-    void removeAttribute(int col) { m_attributes->removeColumn(col); }
+    size_t addAttribute(const std::string &name) { return m_attributes->insertOrResetColumn(name); }
+    void removeAttribute(size_t col) { m_attributes->removeColumn(col); }
     // I don't want to do this, but every so often you will need to update this table
     // use const version by preference
     AttributeTable &getAttributeTable() { return *m_attributes.get(); }
@@ -262,25 +249,31 @@ class PointMap : public PixelBase {
   public:
     double getDisplayMinValue() const {
         return (m_displayed_attribute != -1)
-                   ? m_attributes->getColumn(m_displayed_attribute).getStats().min
+                   ? m_attributes->getColumn(static_cast<size_t>(m_displayed_attribute))
+                         .getStats()
+                         .min
                    : 0;
     }
 
     double getDisplayMaxValue() const {
         return (m_displayed_attribute != -1)
-                   ? m_attributes->getColumn(m_displayed_attribute).getStats().max
+                   ? m_attributes->getColumn(static_cast<size_t>(m_displayed_attribute))
+                         .getStats()
+                         .max
                    : pixelate(m_region.top_right).x;
     }
 
     const DisplayParams &getDisplayParams() const {
-        return m_attributes->getColumn(m_displayed_attribute).getDisplayParams();
+        return m_attributes->getColumn(static_cast<size_t>(m_displayed_attribute))
+            .getDisplayParams();
     }
     // make a local copy of the display params for access speed:
     void setDisplayParams(const DisplayParams &dp, bool apply_to_all = false) {
         if (apply_to_all)
             m_attributes->setDisplayParams(dp);
         else
-            m_attributes->getColumn(m_displayed_attribute).setDisplayParams(dp);
+            m_attributes->getColumn(static_cast<size_t>(m_displayed_attribute))
+                .setDisplayParams(dp);
     }
     //
   public:
@@ -299,7 +292,9 @@ class PointMap : public PixelBase {
         return m_displayed_attribute;
     }
 
-    float getDisplayedSelectedAvg() { return (m_attributes->getSelAvg(m_displayed_attribute)); }
+    float getDisplayedSelectedAvg() {
+        return (m_attributes->getSelAvg(static_cast<size_t>(m_displayed_attribute)));
+    }
 
     double getLocationValue(const Point2f &point);
     //
@@ -676,5 +671,3 @@ inline int q_opposite(int bin) {
 
     return flagoctant(opposing_bin);
 }
-
-#endif
